@@ -71,8 +71,8 @@ main (gint argc, gchar *argv[])
   /**************************************************************************** 
    * New multiplicity function 'NcMultiplicityFuncTinkerMean'
    ****************************************************************************/  
-  mulf = nc_multiplicity_func_new_from_name ("NcMultiplicityFuncTinkerMean");
-
+  mulf = nc_multiplicity_func_tinker_new_full (NC_MULTIPLICITY_FUNC_MASS_DEF_MEAN, 200.0);
+  
   /**************************************************************************** 
    * New mass function object using the objects defined above.
    ****************************************************************************/  
