@@ -29,7 +29,6 @@
 #include <numcosmo/build_cfg.h>
 #include <numcosmo/math/ncm_data.h>
 #include <numcosmo/nc_distance.h>
-#include <numcosmo/nc_snia_dist_cov.h>
 
 G_BEGIN_DECLS
 
@@ -47,8 +46,9 @@ G_BEGIN_DECLS
  * @NC_DATA_SNIA_SIMPLE_SDSS_EMILLE: FIXME
  * @NC_DATA_SNIA_COV_SNLS3_SYS_STAT: FIXME
  * @NC_DATA_SNIA_COV_SNLS3_STAT_ONLY: FIXME
- * @NC_DATA_SNIA_COV_JLA_SNLS3_SDSS_SYS_STAT: JLA SNIa compilation, already includes intrisic, redshift and peculiar velocity variances. 
- * @NC_DATA_SNIA_COV_JLA_SNLS3_SDSS_SYS_STAT_CMPL: JLA SNIa compilation, complete covariance, does *not* include intrisic, redshift and peculiar velocity variances.
+ * @NC_DATA_SNIA_COV_JLA_SNLS3_SDSS_SYS_STAT: JLA SNIa compilation, reduced covariance already includes intrisic, redshift and peculiar velocity variances. 
+ * @NC_DATA_SNIA_COV_JLA_SNLS3_SDSS_SYS_STAT_CMPL: JLA SNIa compilation, complete covariance does *not* include intrisic, redshift and peculiar velocity variances.
+ * @NC_DATA_SNIA_COV_PANTHEON: Pantheon SNIa compilation, reduced covariance already includes intrisic, redshift and peculiar velocity variances.
  * 
  * FIXME
  * 
@@ -69,6 +69,7 @@ typedef enum _NcDataSNIAId
   NC_DATA_SNIA_COV_SNLS3_STAT_ONLY,
   NC_DATA_SNIA_COV_JLA_SNLS3_SDSS_SYS_STAT,
   NC_DATA_SNIA_COV_JLA_SNLS3_SDSS_SYS_STAT_CMPL, 
+  NC_DATA_SNIA_COV_PANTHEON,   
   /* < private > */
   NC_DATA_SNIA_LEN, /*< skip >*/
 } NcDataSNIAId;
@@ -78,16 +79,9 @@ typedef enum _NcDataSNIAId
 #define NC_DATA_SNIA_SIMPLE_LEN ((NC_DATA_SNIA_SIMPLE_END) - (NC_DATA_SNIA_SIMPLE_START) + 1)
 
 #define NC_DATA_SNIA_COV_START NC_DATA_SNIA_COV_SNLS3_SYS_STAT
-#define NC_DATA_SNIA_COV_END NC_DATA_SNIA_COV_JLA_SNLS3_SDSS_SYS_STAT_CMPL
+#define NC_DATA_SNIA_COV_END NC_DATA_SNIA_COV_PANTHEON
 #define NC_DATA_SNIA_COV_LEN ((NC_DATA_SNIA_COV_END) - (NC_DATA_SNIA_COV_START) + 1)
 
-void nc_data_snia_load_cat (NcDataSNIACov *snia_cov, NcDataSNIAId id);
-gchar *nc_data_snia_get_fits (const gchar *filename, gboolean check_size);
-gchar *nc_data_snia_get_catalog (gchar *id);
-gchar *nc_data_snia_get_catalog_by_id (NcDataSNIAId id);
-
 G_END_DECLS
 
 #endif /* _NC_DATA_SNIA_H_ */
-
-
