@@ -30,7 +30,7 @@
 #include <numcosmo/build_cfg.h>
 #include <numcosmo/lss/nc_halo_bias_type.h>
 #include <numcosmo/nc_hicosmo.h>
-#include <numcosmo/lss/nc_mass_function.h>
+#include <numcosmo/lss/nc_halo_mass_function.h>
 
 G_BEGIN_DECLS
 
@@ -54,18 +54,18 @@ struct _NcHaloBiasFunc
 {
   /*< private >*/
   GObject parent_instance;
-  NcMassFunction *mfp;
+  NcHaloMassFunction *mfp;
   NcHaloBiasType *biasf;
 };
 
 GType nc_halo_bias_func_get_type (void) G_GNUC_CONST;
 
-NcHaloBiasFunc *nc_halo_bias_func_new (NcMassFunction *mfp, NcHaloBiasType *biasf);
+NcHaloBiasFunc *nc_halo_bias_func_new (NcHaloMassFunction *mfp, NcHaloBiasType *biasf);
 NcHaloBiasFunc *nc_halo_bias_func_copy (NcHaloBiasFunc *mbiasf);
 void nc_halo_bias_func_free (NcHaloBiasFunc *mbiasf);
 void nc_halo_bias_func_clear (NcHaloBiasFunc **mbiasf);
 
-gdouble nc_halo_bias_func_integrand (NcHaloBiasFunc *mbiasf, NcHICosmo *model, gdouble lnM, gdouble z);
+gdouble nc_halo_bias_func_integrand (NcHaloBiasFunc *mbiasf, NcHICosmo *cosmo, gdouble lnM, gdouble z);
 
 G_END_DECLS
 
