@@ -25,8 +25,8 @@
 
 /**
  * SECTION:nc_halo_bias_type
- * @title: Halo Bias Function Type
- * @short_description: FIXME
+ * @title: NcHaloBiasType
+ * @short_description: Abstract class for halo bias function type.
  *
  * FIXME
  */
@@ -37,7 +37,9 @@
 #include "build_cfg.h"
 
 #include "lss/nc_halo_bias_type.h"
+#include "math/ncm_serialize.h"
 #include "math/ncm_cfg.h"
+#include "math/ncm_util.h"
 
 G_DEFINE_ABSTRACT_TYPE (NcHaloBiasType, nc_halo_bias_type, G_TYPE_OBJECT);
 
@@ -52,11 +54,11 @@ G_DEFINE_ABSTRACT_TYPE (NcHaloBiasType, nc_halo_bias_type, G_TYPE_OBJECT);
 NcHaloBiasType *
 nc_halo_bias_type_new_from_name (gchar *bias_name)
 {
-  GObject *obj = ncm_cfg_create_from_string (bias_name);
+  GObject *obj = ncm_serialize_global_from_string (bias_name);
   GType bias_type = G_OBJECT_TYPE (obj);
 
   if (!g_type_is_a (bias_type, NC_TYPE_HALO_BIAS_TYPE))
-	g_error ("nc_halo_bias_type_new_from_name: NcHaloBiasType %s do not descend from %s\n", bias_name, g_type_name (NC_TYPE_HALO_BIAS_TYPE));
+	g_error ("nc_halo_bias_type_new_from_name: NcHaloBiasType %s do not descend from %s.", bias_name, g_type_name (NC_TYPE_HALO_BIAS_TYPE));
   return NC_HALO_BIAS_TYPE (obj);
 }
 
@@ -107,14 +109,14 @@ nc_halo_bias_type_clear (NcHaloBiasType **biasf)
 static void
 nc_halo_bias_type_init (NcHaloBiasType *nc_halo_bias_type)
 {
-  /* TODO: Add initialization code here */
+  NCM_UNUSED (nc_halo_bias_type);
 }
 
 static void
 _nc_halo_bias_type_finalize (GObject *object)
 {
-  /* TODO: Add deinitalization code here */
-
+  
+  /* Chain up : end */
   G_OBJECT_CLASS (nc_halo_bias_type_parent_class)->finalize (object);
 }
 
