@@ -24,10 +24,13 @@
 
 /**
  * SECTION:grid_one
- * @title: Unidimensional Grid
- * @short_description: FIXME
+ * @title: NcmGrid
+ * @short_description: Unidimensional grid.
+ * @stability: Stable
+ * @include: numcosmo/math/grid_one.h
  *
  * FIXME
+ * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,7 +39,7 @@
 #include "build_cfg.h"
 
 #include "math/grid_one.h"
-#include "math/util.h"
+#include "math/ncm_util.h"
 #include "math/ncm_cfg.h"
 
 /**
@@ -50,7 +53,7 @@
 NcmGrid *
 ncm_grid_new (gulong nnodes)
 {
-  glong i;
+  gulong i;
   NcmGrid *grid = g_slice_new (NcmGrid);
 
   grid->nodes = g_slice_alloc (nnodes * sizeof(mpq_t));
@@ -209,6 +212,8 @@ ncm_grid_set_nodes_d (NcmGrid *grid, NcmGridNodesEndPoints incl, guint32 start,
       a = 0; b = -1; break;
     case NCM_GRID_NODES_NONE:
       a = 1; b = +1; break;
+    default:
+      g_assert_not_reached ();
   }
 
   for (i = 0; i < size; i++)
@@ -320,7 +325,7 @@ ncm_grid_get_double_array (NcmGrid *grid)
 {
   if (grid->data == NULL)
   {
-    gint i;
+    guint i;
     grid->data = g_slice_alloc (sizeof (gdouble) * grid->nnodes);
     for (i = 0; i < grid->nnodes; i++)
       grid->data[i] = mpq_get_d (grid->nodes[i]);
