@@ -27,8 +27,11 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <numcosmo/build_cfg.h>
 
+#ifndef NUMCOSMO_GIR_SCAN
 #include <gsl/gsl_matrix.h>
+#endif /* NUMCOSMO_GIR_SCAN */
 
 G_BEGIN_DECLS
 
