@@ -53,14 +53,19 @@
 #include "math/ncm_spline2d_spline.h"
 #include "math/ncm_powspec.h"
 #include "math/ncm_powspec_filter.h"
+#include "math/ncm_powspec_sphere_proj.h"
 #include "math/ncm_powspec_corr3d.h"
 #include "math/ncm_model.h"
 #include "math/ncm_model_ctrl.h"
 #include "math/ncm_model_builder.h"
 #include "math/ncm_model_mvnd.h"
+#include "math/ncm_model_rosenbrock.h"
+#include "math/ncm_model_funnel.h"
 #include "math/ncm_reparam_linear.h"
 #include "math/ncm_data.h"
 #include "math/ncm_data_gauss_cov_mvnd.h"
+#include "math/ncm_data_rosenbrock.h"
+#include "math/ncm_data_funnel.h"
 #include "math/ncm_stats_vec.h"
 #include "math/ncm_fit_esmcmc_walker_stretch.h"
 #include "math/ncm_data.h"
@@ -68,9 +73,14 @@
 #include "math/ncm_stats_dist1d_spline.h"
 #include "math/ncm_dataset.h"
 #include "math/ncm_fit.h"
+#include "math/ncm_fit_gsl_ls.h"
+#include "math/ncm_fit_gsl_mm.h"
+#include "math/ncm_fit_gsl_mms.h"
 #include "math/ncm_fit_nlopt.h"
 #include "math/ncm_prior_gauss_param.h"
 #include "math/ncm_prior_gauss_func.h"
+#include "math/ncm_fftlog_sbessel_j.h"
+#include "math/ncm_fftlog_sbessel_jljm.h"
 #include "nc_hicosmo.h"
 #include "nc_cbe_precision.h"
 #include "model/nc_hicosmo_qconst.h"
@@ -110,10 +120,9 @@
 #include "lss/nc_multiplicity_func_jenkins.h"
 #include "lss/nc_multiplicity_func_warren.h"
 #include "lss/nc_multiplicity_func_tinker.h"
-#include "lss/nc_multiplicity_func_tinker_mean.h"
-#include "lss/nc_multiplicity_func_tinker_crit.h"
 #include "lss/nc_multiplicity_func_tinker_mean_normalized.h"
 #include "lss/nc_multiplicity_func_crocce.h"
+#include "lss/nc_multiplicity_func_bocquet.h"
 #include "lss/nc_halo_mass_function.h"
 #include "lss/nc_galaxy_acf.h"
 #include "lss/nc_galaxy_redshift_spec.h"
@@ -494,6 +503,7 @@ ncm_cfg_init_full_ptr (gint *argc, gchar ***argv)
   
   ncm_cfg_register_obj (NCM_TYPE_POWSPEC);
   ncm_cfg_register_obj (NCM_TYPE_POWSPEC_FILTER);
+  ncm_cfg_register_obj (NCM_TYPE_POWSPEC_SPHERE_PROJ);
   ncm_cfg_register_obj (NCM_TYPE_POWSPEC_CORR3D);
   
   ncm_cfg_register_obj (NCM_TYPE_MODEL);
@@ -501,6 +511,8 @@ ncm_cfg_init_full_ptr (gint *argc, gchar ***argv)
   ncm_cfg_register_obj (NCM_TYPE_MODEL_BUILDER);
   
   ncm_cfg_register_obj (NCM_TYPE_MODEL_MVND);
+  ncm_cfg_register_obj (NCM_TYPE_MODEL_ROSENBROCK);
+  ncm_cfg_register_obj (NCM_TYPE_MODEL_FUNNEL);
   
   ncm_cfg_register_obj (NCM_TYPE_REPARAM);
   ncm_cfg_register_obj (NCM_TYPE_REPARAM_LINEAR);
@@ -514,15 +526,25 @@ ncm_cfg_init_full_ptr (gint *argc, gchar ***argv)
   ncm_cfg_register_obj (NCM_TYPE_DATASET);
   
   ncm_cfg_register_obj (NCM_TYPE_DATA_GAUSS_COV_MVND);
+  ncm_cfg_register_obj (NCM_TYPE_DATA_ROSENBROCK);
+  ncm_cfg_register_obj (NCM_TYPE_DATA_FUNNEL);
   
   ncm_cfg_register_obj (NCM_TYPE_FIT);
-  
+
+  ncm_cfg_register_obj (NCM_TYPE_FIT_GSL_LS);
+  ncm_cfg_register_obj (NCM_TYPE_FIT_GSL_MM);
+  ncm_cfg_register_obj (NCM_TYPE_FIT_GSL_MMS);
+ 
 #ifdef NUMCOSMO_HAVE_NLOPT
   ncm_cfg_register_obj (NCM_TYPE_FIT_NLOPT);
 #endif /* NUMCOSMO_HAVE_NLOPT */
+
   ncm_cfg_register_obj (NCM_TYPE_PRIOR_GAUSS_PARAM);
   ncm_cfg_register_obj (NCM_TYPE_PRIOR_GAUSS_FUNC);
   
+  ncm_cfg_register_obj (NCM_TYPE_FFTLOG_SBESSEL_J);
+  ncm_cfg_register_obj (NCM_TYPE_FFTLOG_SBESSEL_JLJM);
+
   ncm_cfg_register_obj (NCM_TYPE_DATA);
   
   ncm_cfg_register_obj (NCM_TYPE_STATS_DIST1D_EPDF);
@@ -582,10 +604,9 @@ ncm_cfg_init_full_ptr (gint *argc, gchar ***argv)
   ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_JENKINS);
   ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_WARREN);
   ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_TINKER);
-  ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_TINKER_MEAN);
-  ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_TINKER_CRIT);
   ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_TINKER_MEAN_NORMALIZED);
   ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_CROCCE);
+  ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_BOCQUET);
   
   ncm_cfg_register_obj (NC_TYPE_HALO_MASS_FUNCTION);
   
@@ -873,15 +894,16 @@ _ncm_cfg_mpi_cmd_handler (gpointer user_data)
           gint input_recv    = 0;
           MPI_Request wr_request;
           
-          NCM_MPI_JOB_DEBUG_PRINT ("#[%3d %3d] Slave received a work request.\n", _mpi_ctrl.size, _mpi_ctrl.rank);
+          NCM_MPI_JOB_DEBUG_PRINT ("#[%3d %3d] Slave received a work request, command %d.\n",
+              _mpi_ctrl.size, _mpi_ctrl.rank, cmd);
 
           MPI_Recv (input_buf, input_len, input_dtype, NCM_MPI_CTRL_MASTER_ID, NCM_MPI_CTRL_TAG_WORK_INPUT, MPI_COMM_WORLD, &status);
           MPI_Get_count (&status, input_dtype, &input_recv);
-          
+
           NCM_MPI_JOB_DEBUG_PRINT ("#[%3d %3d] Slave received work data: %d-bytes, working...\n", _mpi_ctrl.size, _mpi_ctrl.rank, input_len);
 
           g_assert_cmpint (input_recv, ==, input_len);
-          
+
           ncm_mpi_job_unpack_input (mpi_job, input_buf, input);
           
           bd.obj = ncm_mpi_job_create_return (mpi_job);
@@ -889,10 +911,11 @@ _ncm_cfg_mpi_cmd_handler (gpointer user_data)
           ncm_mpi_job_run (mpi_job, input, bd.obj);
           bd.buf = ncm_mpi_job_pack_return (mpi_job, bd.obj);
           
-          NCM_MPI_JOB_DEBUG_PRINT ("#[%3d %3d] Job done, sending result!\n", _mpi_ctrl.size, _mpi_ctrl.rank);
+          NCM_MPI_JOB_DEBUG_PRINT ("#[%3d %3d] Job done, sending result, length %d!\n",
+              _mpi_ctrl.size, _mpi_ctrl.rank, return_len);
           
           MPI_Isend (bd.buf, return_len, return_dtype, NCM_MPI_CTRL_MASTER_ID, NCM_MPI_CTRL_TAG_WORK_RETURN, MPI_COMM_WORLD, &wr_request);
-          
+
           g_array_append_val (work_ret_request, wr_request);
           g_array_append_val (work_ret_bufs,    bd);
         }
@@ -915,7 +938,8 @@ _ncm_cfg_mpi_cmd_handler (gpointer user_data)
         gint done = 0;
         
         MPI_Test (&g_array_index (work_ret_request, MPI_Request, i), &done, &status);
-        NCM_MPI_JOB_DEBUG_PRINT ("#[%3d %3d] Send %d is %s!\n", _mpi_ctrl.size, _mpi_ctrl.rank, i, done ? "done" : "not done");
+        NCM_MPI_JOB_DEBUG_PRINT ("#[%3d %3d] Send %d is %s!\n",
+            _mpi_ctrl.size, _mpi_ctrl.rank, i, done ? "done" : "not done");
         
         if (done)
         {
@@ -930,7 +954,8 @@ _ncm_cfg_mpi_cmd_handler (gpointer user_data)
       }
     }
     
-    NCM_MPI_JOB_DEBUG_PRINT ("#[%3d %3d] Finished command, %d requests left, %d%s\n", _mpi_ctrl.size, _mpi_ctrl.rank, work_ret_request->len, cmd, end ? ", exiting!" : ".");
+    NCM_MPI_JOB_DEBUG_PRINT ("#[%3d %3d] Finished command %d, %d requests left%s\n",
+        _mpi_ctrl.size, _mpi_ctrl.rank, cmd, work_ret_request->len, end ? ", exiting!" : ".");
     
     if (end)
       break;
@@ -1292,7 +1317,7 @@ ncm_cfg_msg_sepa (void)
  *
  * FIXME
  *
- * Returns: FIXME
+ * Returns: (transfer full): FIXME
  */
 gchar *
 ncm_cfg_get_fullpath (const gchar *filename, ...)
