@@ -44,7 +44,7 @@
  * This object computes the function (see #NcmFftlog)
  * $$Y_n = \int_0^\infty t^{\frac{2\pi i n}{L}} K(t) dt,$$
  * where the kernel are the spherical Bessel function
- * of the first kind multiplied by a power law, 
+ * of the first kind multiplied by a power law,
  *
  * \begin{equation}\label{eq:kerneljl}
  * K(t) = t^q j_{\ell}(t).
@@ -75,7 +75,7 @@
  * \begin{equation*}
  * K(t) = j_{\ell}(t) \,\, .
  * \end{equation*}
- * Where, $t=kr$ and $r^{(2-2n+\ell)}$ was taken out of the integral. 
+ * Where, $t=kr$ and $r^{(2-2n+\ell)}$ was taken out of the integral.
  * Comparing this kernel with the one defined in Eq. \eqref{eq:kerneljl}, we have $q=0$.
  *
  * But instead, one might choose another format for the function,
@@ -86,7 +86,7 @@
  * \begin{equation*}
  * K(t) = t^{2-2n} \, j_{\ell}(t) \,\, ,
  * \end{equation*}
- * which evaluates the same integral, but now with $q=2-2n$, and 
+ * which evaluates the same integral, but now with $q=2-2n$, and
  * in this case, the term $r^{\ell}$ was the one taken out of the integral.
  * Therefore, the parameter $q$ is the power of the wavenumber $k$ times the distance $r$, $t=kr$,
  * included to the kernel with the spherical Bessel function.
@@ -95,7 +95,7 @@
  * In general, $q=0$ is an accurate and fast choice to make, but it is interesting to
  * perform tests to evaluate which kernel format fits best for each type of integral.
  *
- * The #NcmPowspecCorr3d object already evaluates Eq. \eqref{eq:xi_multipoles} 
+ * The #NcmPowspecCorr3d object already evaluates Eq. \eqref{eq:xi_multipoles}
  * for the case of the monopole, $n=\ell=0$, with support for redshift evolution.
  *
  */
@@ -113,6 +113,11 @@
 #include <gsl/gsl_sf_result.h>
 #include <gsl/gsl_sf_gamma.h>
 #include <gsl/gsl_sf_trig.h>
+#include <gsl/gsl_math.h>
+#include <complex.h>
+#ifdef NUMCOSMO_HAVE_FFTW3
+#include <fftw3.h>
+#endif /* NUMCOSMO_HAVE_FFTW3 */
 #include <math.h>
 #endif /* NUMCOSMO_GIR_SCAN */
 
@@ -135,9 +140,10 @@ G_DEFINE_TYPE_WITH_PRIVATE (NcmFftlogSBesselJ, ncm_fftlog_sbessel_j, NCM_TYPE_FF
 static void
 ncm_fftlog_sbessel_j_init (NcmFftlogSBesselJ *fftlog_jl)
 {
-  fftlog_jl->priv      = ncm_fftlog_sbessel_j_get_instance_private (fftlog_jl);
-  fftlog_jl->priv->ell = 0;
-  fftlog_jl->priv->q   = 0.0;
+  NcmFftlogSBesselJPrivate * const self = fftlog_jl->priv = ncm_fftlog_sbessel_j_get_instance_private (fftlog_jl);
+  
+  self->ell = 0;
+  self->q   = 0.0;
 }
 
 static void
@@ -237,23 +243,25 @@ ncm_fftlog_sbessel_j_class_init (NcmFftlogSBesselJClass *klass)
 static void
 _ncm_fftlog_sbessel_j_get_Ym (NcmFftlog *fftlog, gpointer Ym_0)
 {
-  NcmFftlogSBesselJ *fftlog_jl = NCM_FFTLOG_SBESSEL_J (fftlog);
-  const gdouble pi_sqrt        = sqrt (M_PI);
-  const gdouble twopi_Lt       = 2.0 * M_PI / ncm_fftlog_get_full_length (fftlog);
-  const gint Nf                = ncm_fftlog_get_full_size (fftlog);
+  NcmFftlogSBesselJ *fftlog_jl          = NCM_FFTLOG_SBESSEL_J (fftlog);
+  NcmFftlogSBesselJPrivate * const self = fftlog_jl->priv;
+  
+  const gdouble pi_sqrt  = sqrt (M_PI);
+  const gdouble twopi_Lt = 2.0 * M_PI / ncm_fftlog_get_full_length (fftlog);
+  const gint Nf          = ncm_fftlog_get_full_size (fftlog);
   
 #ifdef NUMCOSMO_HAVE_FFTW3
   fftw_complex *Ym_base = (fftw_complex *) Ym_0;
   gint i;
   
-  if (fftlog_jl->priv->q == 0.5)
+  if (self->q == 0.5)
   {
     for (i = 0; i < Nf; i++)
     {
       const gint phys_i             = ncm_fftlog_get_mode_index (fftlog, i);
       const complex double a        = twopi_Lt * phys_i * I;
       const complex double A        = a + 0.5;
-      const complex double xup      = 0.5 * (1.0 + 1.0 * fftlog_jl->priv->ell + A);
+      const complex double xup      = 0.5 * (1.0 + 1.0 * self->ell + A);
       const complex double two_x_m1 = cpow (2.0, A - 1.0);
       complex double U;
       
@@ -268,15 +276,15 @@ _ncm_fftlog_sbessel_j_get_Ym (NcmFftlog *fftlog, gpointer Ym_0)
   }
   else
   {
-    const gdouble q = fftlog_jl->priv->q;
+    const gdouble q = self->q;
     
     for (i = 0; i < Nf; i++)
     {
       const gint phys_i             = ncm_fftlog_get_mode_index (fftlog, i);
       const complex double a        = twopi_Lt * phys_i * I;
       const complex double A        = a + q;
-      const complex double xup      = 0.5 * (1.0 + 1.0 * fftlog_jl->priv->ell + A);
-      const complex double xdw      = 0.5 * (2.0 + 1.0 * fftlog_jl->priv->ell - A);
+      const complex double xup      = 0.5 * (1.0 + 1.0 * self->ell + A);
+      const complex double xdw      = 0.5 * (2.0 + 1.0 * self->ell - A);
       const complex double two_x_m1 = cpow (2.0, A - 1.0);
       complex double U;
       
@@ -334,13 +342,14 @@ ncm_fftlog_sbessel_j_new (guint ell, gdouble lnr0, gdouble lnk0, gdouble Lk, gui
 void
 ncm_fftlog_sbessel_j_set_ell (NcmFftlogSBesselJ *fftlog_jl, const guint ell)
 {
-  if (fftlog_jl->priv->ell != ell)
+  NcmFftlogSBesselJPrivate * const self = fftlog_jl->priv;
+  
+  if (self->ell != ell)
   {
     NcmFftlog *fftlog = NCM_FFTLOG (fftlog_jl);
     
-    fftlog_jl->priv->ell = ell;
-    fftlog->prepared     = FALSE;
-    fftlog->evaluated    = FALSE;
+    self->ell = ell;
+    ncm_fftlog_reset (fftlog);
   }
 }
 
@@ -353,13 +362,15 @@ ncm_fftlog_sbessel_j_set_ell (NcmFftlogSBesselJ *fftlog_jl, const guint ell)
 guint
 ncm_fftlog_sbessel_j_get_ell (NcmFftlogSBesselJ *fftlog_jl)
 {
-  return fftlog_jl->priv->ell;
+  NcmFftlogSBesselJPrivate * const self = fftlog_jl->priv;
+  
+  return self->ell;
 }
 
 /**
  * ncm_fftlog_sbessel_j_set_q:
  * @fftlog_jl: a #NcmFftlogSBesselJ
- * @q: Spherical Bessel power $q$
+ * @q: Spherical Bessel power factor $q$
  *
  * Sets @q as the Spherical Bessel power.
  *
@@ -367,13 +378,14 @@ ncm_fftlog_sbessel_j_get_ell (NcmFftlogSBesselJ *fftlog_jl)
 void
 ncm_fftlog_sbessel_j_set_q (NcmFftlogSBesselJ *fftlog_jl, const gdouble q)
 {
-  if (fftlog_jl->priv->q != q)
+  NcmFftlogSBesselJPrivate * const self = fftlog_jl->priv;
+  
+  if (self->q != q)
   {
     NcmFftlog *fftlog = NCM_FFTLOG (fftlog_jl);
     
-    fftlog_jl->priv->q = q;
-    fftlog->prepared   = FALSE;
-    fftlog->evaluated  = FALSE;
+    self->q = q;
+    ncm_fftlog_reset (fftlog);
   }
 }
 
@@ -386,7 +398,9 @@ ncm_fftlog_sbessel_j_set_q (NcmFftlogSBesselJ *fftlog_jl, const gdouble q)
 gdouble
 ncm_fftlog_sbessel_j_get_q (NcmFftlogSBesselJ *fftlog_jl)
 {
-  return fftlog_jl->priv->q;
+  NcmFftlogSBesselJPrivate * const self = fftlog_jl->priv;
+  
+  return self->q;
 }
 
 /**
@@ -402,13 +416,14 @@ ncm_fftlog_sbessel_j_get_q (NcmFftlogSBesselJ *fftlog_jl)
 void
 ncm_fftlog_sbessel_j_set_best_lnr0 (NcmFftlogSBesselJ *fftlog_jl)
 {
-  NcmFftlog *fftlog = NCM_FFTLOG (fftlog_jl);
+  NcmFftlogSBesselJPrivate * const self = fftlog_jl->priv;
+  NcmFftlog *fftlog                     = NCM_FFTLOG (fftlog_jl);
   
   gint signp = 0;
   
   const gdouble lnk0      = ncm_fftlog_get_lnk0 (fftlog);
   const gdouble Lk        = ncm_fftlog_get_length (fftlog);
-  const gdouble ell       = fftlog_jl->priv->ell;
+  const gdouble ell       = self->ell;
   const gdouble lnc0      = (ell == 0) ? 0.0 : ((ell - 1.0) * Lk + 2.0 * (ell + 1.0) * M_LN2 - ncm_c_lnpi () + 2.0 * lgamma_r (1.5 + ell, &signp)) / (2.0 * (1.0 + ell));
   const gdouble best_lnr0 = -lnk0 + lnc0;
   
@@ -428,13 +443,14 @@ ncm_fftlog_sbessel_j_set_best_lnr0 (NcmFftlogSBesselJ *fftlog_jl)
 void
 ncm_fftlog_sbessel_j_set_best_lnk0 (NcmFftlogSBesselJ *fftlog_jl)
 {
-  NcmFftlog *fftlog = NCM_FFTLOG (fftlog_jl);
+  NcmFftlogSBesselJPrivate * const self = fftlog_jl->priv;
+  NcmFftlog *fftlog                     = NCM_FFTLOG (fftlog_jl);
   
   gint signp = 0;
   
   const gdouble lnr0      = ncm_fftlog_get_lnr0 (fftlog);
   const gdouble Lk        = ncm_fftlog_get_length (fftlog);
-  const gdouble ell       = fftlog_jl->priv->ell;
+  const gdouble ell       = self->ell;
   const gdouble lnc0      = (ell == 0) ? 0.0 : ((ell - 1.0) * Lk + 2.0 * (ell + 1.0) * M_LN2 - ncm_c_lnpi () + 2.0 * lgamma_r (1.5 + ell, &signp)) / (2.0 * (1.0 + ell));
   const gdouble best_lnk0 = -lnr0 + lnc0;
   
