@@ -2271,86 +2271,6 @@ ncm_fit_get_covar (NcmFit *fit)
   return ncm_matrix_dup (fit->fstate->covar);
 }
 
-/**
- * ncm_fit_residual_ks_test:
- * @fit: a #NcmFit.
- * @o_mean: (out): FIXME
- * @o_sd: (out): FIXME
- * @o_skew: (out): FIXME
- * @o_kurtosis: (out): FIXME
- * @o_max: (out): FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-gdouble
-ncm_fit_residual_ks_test (NcmFit *fit, gdouble *o_mean, gdouble *o_sd, gdouble *o_skew, gdouble *o_kurtosis, gdouble *o_max)
-{
-  if (!ncm_dataset_has_leastsquares_f (fit->lh->dset))
-    return - 1.0;
-  else
-  {
-    NcmVector *f = fit->fstate->is_least_squares ? ncm_vector_ref (fit->fstate->ls_f) : ncm_vector_new (fit->fstate->data_len);
-    guint n = ncm_vector_len (f);
-    gdouble *d = ncm_vector_data (f);
-    gdouble mean, sd;
-    gdouble max = 0.0;
-    guint i;
-
-    ncm_fit_ls_f (fit, f);
-
-    if (FALSE)
-    {
-      for (i = 0; i < n; i++)
-      {
-        const gdouble x = ncm_vector_get (f, i);
-        printf ("% 20.15g\n", x );
-      }
-    }
-
-    gsl_sort_vector (ncm_vector_gsl (f));
-
-    mean = gsl_stats_mean (d, ncm_vector_stride (f), n);
-    sd   = gsl_stats_sd_m (d, ncm_vector_stride (f), n, mean);
-
-    for (i = 0; i < n; i++)
-    {
-      const gdouble prob = (i + 1.0) / (n * 1.0);
-      const gdouble x = ncm_vector_get (f, i);
-      const gdouble pgauss = gsl_cdf_gaussian_P (x - mean, sd);
-      max = GSL_MAX (max, fabs (prob - pgauss));
-    }
-
-    if (o_mean != NULL)
-      *o_mean = mean;
-    if (o_sd != NULL)
-      *o_sd = sd;
-
-    if (o_skew != NULL)
-      *o_skew = gsl_stats_skew_m_sd (d, ncm_vector_stride (f), n, mean, sd);
-
-    if (o_kurtosis != NULL)
-      *o_kurtosis = gsl_stats_kurtosis_m_sd (d, ncm_vector_stride (f), n, mean, sd);
-
-    if (o_max != NULL)
-      *o_max = max;
-
-    if (FALSE)
-    {
-      gdouble w, pw;
-      gint ret;
-
-      ncm_util_swilk (d, n, &w, &pw, &ret);
-
-      printf ("Swilk test % 20.15g % 20.15g %d\n", w, pw, ret);
-    }
-
-    ncm_vector_free (f);
-    return ncm_util_KScdf (n, max);
-  }
-}
-
 typedef struct _FitDProb
 {
   NcmMSetPIndex pi;
