@@ -288,7 +288,7 @@ _ncm_fit_esmcmc_constructed (GObject *object)
     g_array_set_size (self->offboard, self->nwalkers);
     
     if (self->walker == NULL)
-      self->walker = ncm_fit_esmcmc_walker_new_from_name ("NcmFitESMCMCWalkerStretch");
+      self->walker = ncm_fit_esmcmc_walker_new_from_name ("NcmFitESMCMCWalkerAPES");
     
     ncm_fit_esmcmc_walker_set_size (self->walker, self->nwalkers);
     ncm_fit_esmcmc_walker_set_nparams (self->walker, self->fparam_len);
@@ -1103,7 +1103,7 @@ ncm_fit_esmcmc_get_offboard_ratio_last_update (NcmFitESMCMC *esmcmc)
 }
 
 void
-_ncm_fit_esmcmc_update (NcmFitESMCMC *esmcmc, guint ki, guint kf)
+_ncm_fit_esmcmc_update (NcmFitESMCMC *esmcmc, guint ki, guint kf, gboolean init)
 {
   NcmFitESMCMCPrivate * const self = esmcmc->priv;
   const guint step                 = self->nwalkers * ((self->n / self->interm_log) == 0 ? 1 : (self->n / self->interm_log));
@@ -1125,20 +1125,30 @@ _ncm_fit_esmcmc_update (NcmFitESMCMC *esmcmc, guint ki, guint kf)
     self->cur_sample_id++;
     ncm_timer_task_increment (self->nt);
     
-    self->ntotal++;
-    self->ntotal_lup++;
+    if (!init)
+    {
+      self->ntotal++;
+      self->ntotal_lup++;
+    }
     
     if (g_array_index (self->accepted, gboolean, k))
     {
-      self->naccepted++;
-      self->naccepted_lup++;
+      if (!init)
+      {
+        self->naccepted++;
+        self->naccepted_lup++;
+      }
+
       g_array_index (self->accepted, gboolean, k) = FALSE;
     }
     
     if (g_array_index (self->offboard, gboolean, k))
     {
-      self->noffboard++;
-      self->noffboard_lup++;
+      if (!init)
+      {
+        self->noffboard++;
+        self->noffboard_lup++;
+      }
       g_array_index (self->offboard, gboolean, k) = FALSE;
     }
   }
@@ -1154,7 +1164,7 @@ _ncm_fit_esmcmc_update (NcmFitESMCMC *esmcmc, guint ki, guint kf)
       
       if ((self->nt->pos_time - self->nt->last_log_time) > self->log_time_interval)
         log_timeout = ((self->cur_sample_id + 1) % self->nwalkers == 0);
-
+      
       if (log_timeout || (stepi == 0) || (self->nt->task_pos == self->nt->task_len))
       {
         NcmVector *e_var = ncm_mset_catalog_peek_current_e_var (self->mcat);
@@ -1162,9 +1172,12 @@ _ncm_fit_esmcmc_update (NcmFitESMCMC *esmcmc, guint ki, guint kf)
         /* guint acc = stepi == 0 ? step : stepi; */
         ncm_mset_catalog_log_current_stats (self->mcat);
         ncm_mset_catalog_log_current_chain_stats (self->mcat);
-        g_message ("# NcmFitESMCMC:acceptance ratio %7.4f%% (last update %7.4f%%), offboard ratio %7.4f%% (last update %7.4f%%).\n",
-                   ncm_fit_esmcmc_get_accept_ratio (esmcmc) * 100.0, ncm_fit_esmcmc_get_accept_ratio_last_update (esmcmc) * 100.0,
-                   ncm_fit_esmcmc_get_offboard_ratio (esmcmc) * 100.0, ncm_fit_esmcmc_get_offboard_ratio_last_update (esmcmc) * 100.0);
+        if (!init)
+        {
+          g_message ("# NcmFitESMCMC:acceptance ratio %7.4f%% (last update %7.4f%%), offboard ratio %7.4f%% (last update %7.4f%%).\n",
+              ncm_fit_esmcmc_get_accept_ratio (esmcmc) * 100.0, ncm_fit_esmcmc_get_accept_ratio_last_update (esmcmc) * 100.0,
+              ncm_fit_esmcmc_get_offboard_ratio (esmcmc) * 100.0, ncm_fit_esmcmc_get_offboard_ratio_last_update (esmcmc) * 100.0);
+        }
         g_message ("# NcmFitESMCMC:last ensemble variance of -2ln(L): % 22.15g (2n = %d), min(-2ln(L)) = % 22.15g.\n",
                    e_var != NULL ? ncm_vector_get (e_var, NCM_FIT_ESMCMC_M2LNL_ID) : GSL_POSINF,
                    2 * self->fparam_len,
@@ -1198,9 +1211,12 @@ _ncm_fit_esmcmc_update (NcmFitESMCMC *esmcmc, guint ki, guint kf)
         ncm_fit_log_state (self->fit);
         ncm_mset_catalog_log_current_stats (self->mcat);
         ncm_mset_catalog_log_current_chain_stats (self->mcat);
-        g_message ("# NcmFitESMCMC:acceptance ratio %7.4f%% (last update %7.4f%%), offboard ratio %7.4f%% (last update %7.4f%%).\n",
-                   ncm_fit_esmcmc_get_accept_ratio (esmcmc) * 100.0, ncm_fit_esmcmc_get_accept_ratio_last_update (esmcmc) * 100.0,
-                   ncm_fit_esmcmc_get_offboard_ratio (esmcmc) * 100.0, ncm_fit_esmcmc_get_offboard_ratio_last_update (esmcmc) * 100.0);
+        if (!init)
+        {
+          g_message ("# NcmFitESMCMC:acceptance ratio %7.4f%% (last update %7.4f%%), offboard ratio %7.4f%% (last update %7.4f%%).\n",
+              ncm_fit_esmcmc_get_accept_ratio (esmcmc) * 100.0, ncm_fit_esmcmc_get_accept_ratio_last_update (esmcmc) * 100.0,
+              ncm_fit_esmcmc_get_offboard_ratio (esmcmc) * 100.0, ncm_fit_esmcmc_get_offboard_ratio_last_update (esmcmc) * 100.0);
+        }
         g_message ("# NcmFitESMCMC:last ensemble variance of -2ln(L): % 22.15g (2n = %d), min(-2ln(L)) = % 22.15g.\n",
                    e_var != NULL ? ncm_vector_get (e_var, NCM_FIT_ESMCMC_M2LNL_ID) : GSL_POSINF,
                    2 * self->fparam_len,
@@ -1246,7 +1262,7 @@ _ncm_fit_esmcmc_gen_init_points_mpi (NcmFitESMCMC *esmcmc, const glong i, const
     g_ptr_array_add (thetastar_out_a, thetastar_out_k);
   }
   
-  ncm_mpi_job_run_array (self->mj, thetastar_in_a, thetastar_out_a);
+  ncm_mpi_job_run_array_async (self->mj, thetastar_in_a, thetastar_out_a);
   
   k = i;
   
@@ -1299,7 +1315,11 @@ _ncm_fit_esmcmc_gen_init_points_mt_eval (glong i, glong f, gpointer data)
       g_mutex_unlock (&self->resample_lock);
       
       ncm_mset_fparams_set_vector (fit_k->mset, theta_k);
-      ncm_fit_m2lnL_val (fit_k, m2lnL);
+      if (!ncm_mset_params_valid (fit_k->mset) || !ncm_mset_params_valid_bounds (fit_k->mset))
+        m2lnL[0] = GSL_POSINF;
+      else
+        ncm_fit_m2lnL_val (fit_k, m2lnL);
+
     } while (!gsl_finite (m2lnL[0]));
     
     if (fk_ptr[0]->funcs_array != NULL)
@@ -1321,32 +1341,91 @@ _ncm_fit_esmcmc_gen_init_points_mt_eval (glong i, glong f, gpointer data)
   ncm_memory_pool_return (fk_ptr);
 }
 
+static gint
+_ncm_fit_esmcmc_check_init_points (NcmFitESMCMC *esmcmc)
+{
+  NcmFitESMCMCPrivate * const self = esmcmc->priv;
+  GArray *inrange   = g_array_new (FALSE, FALSE, sizeof (gint));
+  gdouble m2lnL_min = GSL_POSINF;
+  gdouble m2lnL_max = GSL_NEGINF;
+  const gdouble cut = 1.0e6;
+  gint i;
+
+  for (i = 0; i < self->nwalkers; i++)
+  {
+    NcmVector *full_theta_i = g_ptr_array_index (self->full_theta, i);
+    const gdouble m2lnL_i   = ncm_vector_get (full_theta_i, NCM_FIT_ESMCMC_M2LNL_ID);
+
+    m2lnL_min = MIN (m2lnL_min, m2lnL_i);
+    m2lnL_max = MAX (m2lnL_max, m2lnL_i);
+  }
+
+  if (m2lnL_max - m2lnL_min > -cut * GSL_LOG_DBL_EPSILON)
+  {
+    for (i = 0; i < self->nwalkers; i++)
+    {
+      NcmVector *full_theta_i = g_ptr_array_index (self->full_theta, i);
+      const gdouble m2lnL_i   = ncm_vector_get (full_theta_i, NCM_FIT_ESMCMC_M2LNL_ID);
+
+      if (m2lnL_i - m2lnL_min < -cut * GSL_LOG_DBL_EPSILON)
+        g_array_append_val (inrange, i);
+    }
+
+    if (inrange->len < self->nwalkers)
+    {
+      for (i = 0; i < inrange->len; i++)
+      {
+        const gint j = g_array_index (inrange, gint, i);
+        if (i != j)
+        {
+          NcmVector *full_theta_i = g_ptr_array_index (self->full_theta, i);
+          NcmVector *full_theta_j = g_ptr_array_index (self->full_theta, j);
+
+          ncm_vector_memcpy (full_theta_i, full_theta_j);
+        }
+      }
+    }
+  }
+  else
+    return self->nwalkers;
+
+  {
+    gint len = inrange->len;
+    g_array_unref (inrange);
+    return len;
+  }
+}
+
 static void
 _ncm_fit_esmcmc_gen_init_points (NcmFitESMCMC *esmcmc, const gboolean use_mpi)
 {
   NcmFitESMCMCPrivate * const self = esmcmc->priv;
+  gint len;
   
   if (self->cur_sample_id + 1 == self->nwalkers)
     return;
   else if (self->cur_sample_id + 1 > self->nwalkers)
     g_error ("_ncm_fit_esmcmc_gen_init_points: initial points already generated.");
   
-  if (self->nthreads > 1)
+  ncm_mset_catalog_set_sync_mode (self->mcat, NCM_MSET_CATALOG_SYNC_DISABLE);
+
+  len = self->cur_sample_id + 1;
+  do
   {
-    ncm_mset_catalog_set_sync_mode (self->mcat, NCM_MSET_CATALOG_SYNC_DISABLE);
-    
-    if (use_mpi)
-      _ncm_fit_esmcmc_gen_init_points_mpi (esmcmc, self->cur_sample_id + 1, self->nwalkers);
+    if (self->nthreads > 1)
+    {
+      if (use_mpi)
+        _ncm_fit_esmcmc_gen_init_points_mpi (esmcmc, len, self->nwalkers);
+      else
+        ncm_func_eval_threaded_loop_full (&_ncm_fit_esmcmc_gen_init_points_mt_eval, len, self->nwalkers, esmcmc);
+    }
     else
-      ncm_func_eval_threaded_loop_full (&_ncm_fit_esmcmc_gen_init_points_mt_eval, self->cur_sample_id + 1, self->nwalkers, esmcmc);
-  }
-  else
-  {
-    ncm_mset_catalog_set_sync_mode (self->mcat, NCM_MSET_CATALOG_SYNC_DISABLE);
-    _ncm_fit_esmcmc_gen_init_points_mt_eval (self->cur_sample_id + 1, self->nwalkers, esmcmc);
-  }
-  
-  _ncm_fit_esmcmc_update (esmcmc, self->cur_sample_id + 1, self->nwalkers);
+      _ncm_fit_esmcmc_gen_init_points_mt_eval (len, self->nwalkers, esmcmc);
+
+    len = _ncm_fit_esmcmc_check_init_points (esmcmc);
+  } while (len < self->nwalkers);
+
+  _ncm_fit_esmcmc_update (esmcmc, self->cur_sample_id + 1, self->nwalkers, TRUE);
   ncm_mset_catalog_sync (self->mcat, FALSE);
 }
 
@@ -1663,7 +1742,7 @@ ncm_fit_esmcmc_run (NcmFitESMCMC *esmcmc, guint n)
       g_message ("# NcmFitESMCMC: Calculating [%06d] Ensemble Sampler Markov Chain Monte Carlo runs [%s]\n",
                  self->n, ncm_fit_esmcmc_walker_desc (self->walker));
     }
-      break;
+    break;
     case NCM_FIT_RUN_MSGS_NONE:
       break;
   }
@@ -1710,8 +1789,7 @@ _ncm_fit_esmcmc_eval_mpi (NcmFitESMCMC *esmcmc, const glong i, const glong f)
     
     /*ncm_vector_log_vals (g_ptr_array_index (self->full_thetastar_inout, k), "#  FULL IN: ", "% 22.15g", TRUE);*/
     
-    /*if (ncm_mset_fparam_valid_bounds (self->fit->mset, thetastar))*/
-    if (ncm_mset_fparam_validate_all (self->fit->mset, thetastar)) /* TEST! */
+    if (ncm_mset_fparam_valid_bounds (self->fit->mset, thetastar))
     {
       g_ptr_array_add (thetastar_in_a,  thetastar_in_k);
       g_ptr_array_add (thetastar_out_a, thetastar_out_k);
@@ -1722,7 +1800,7 @@ _ncm_fit_esmcmc_eval_mpi (NcmFitESMCMC *esmcmc, const glong i, const glong f)
     }
   }
   
-  ncm_mpi_job_run_array (self->mj, thetastar_in_a, thetastar_out_a);
+  ncm_mpi_job_run_array_async (self->mj, thetastar_in_a, thetastar_out_a);
   
   for (k = i; k < f; k++)
   {
@@ -1767,11 +1845,13 @@ _ncm_fit_esmcmc_mt_eval (glong i, glong f, gpointer data)
     
     ncm_fit_esmcmc_walker_step (self->walker, self->theta, self->m2lnL, thetastar, k);
     
-    /*if (ncm_mset_fparam_valid_bounds (fit_k->mset, thetastar))*/
-    if (ncm_mset_fparam_validate_all (fit_k->mset, thetastar)) /* TEST! */
+    if (ncm_mset_fparam_valid_bounds (fit_k->mset, thetastar))
     {
       ncm_mset_fparams_set_vector (fit_k->mset, thetastar);
-      ncm_fit_m2lnL_val (fit_k, m2lnL_star);
+      if (!ncm_mset_params_valid (fit_k->mset))
+        m2lnL_star[0] = GSL_POSINF;
+      else
+        ncm_fit_m2lnL_val (fit_k, m2lnL_star);
       
       if (gsl_finite (m2lnL_star[0]))
       {
@@ -1781,6 +1861,7 @@ _ncm_fit_esmcmc_mt_eval (glong i, glong f, gpointer data)
     }
     else
     {
+      /*ncm_vector_log_vals (thetastar, "thetastar", "% 22.15g", TRUE);*/
       g_array_index (self->offboard, gboolean, k) = TRUE;
     }
     
@@ -1853,7 +1934,7 @@ _ncm_fit_esmcmc_run (NcmFitESMCMC *esmcmc)
   if (self->n > 0)
   {
     _ncm_fit_esmcmc_get_jumps (esmcmc, ki, self->nwalkers);
-    ncm_fit_esmcmc_walker_setup (self->walker, self->theta, self->m2lnL, ki, self->nwalkers, rng);
+    ncm_fit_esmcmc_walker_setup (self->walker, self->fit->mset, self->theta, self->m2lnL, ki, self->nwalkers, rng);
     
     if (ki < nwalkers_2)
     {
@@ -1867,20 +1948,20 @@ _ncm_fit_esmcmc_run (NcmFitESMCMC *esmcmc)
     
     ncm_fit_esmcmc_walker_clean (self->walker, ki, self->nwalkers);
     
-    _ncm_fit_esmcmc_update (esmcmc, ki, self->nwalkers);
+    _ncm_fit_esmcmc_update (esmcmc, ki, self->nwalkers, FALSE);
     ncm_mset_catalog_timed_sync (self->mcat, FALSE);
     
     for (i = 1; i < self->n; i++)
     {
       _ncm_fit_esmcmc_get_jumps (esmcmc, 0, self->nwalkers);
-      ncm_fit_esmcmc_walker_setup (self->walker, self->theta, self->m2lnL, 0, self->nwalkers, rng);
+      ncm_fit_esmcmc_walker_setup (self->walker, self->fit->mset, self->theta, self->m2lnL, 0, self->nwalkers, rng);
       
       run (esmcmc, 0, nwalkers_2);
       run (esmcmc, nwalkers_2, self->nwalkers);
       
       ncm_fit_esmcmc_walker_clean (self->walker, 0, self->nwalkers);
       
-      _ncm_fit_esmcmc_update (esmcmc, 0, self->nwalkers);
+      _ncm_fit_esmcmc_update (esmcmc, 0, self->nwalkers, FALSE);
       ncm_mset_catalog_timed_sync (self->mcat, FALSE);
     }
   }
@@ -1930,7 +2011,7 @@ ncm_fit_esmcmc_run_lre (NcmFitESMCMC *esmcmc, guint prerun, gdouble lre)
     gdouble m             = n * lerror2 / lre2;
     guint runs            = ((m - n) > 1000.0) ? MIN (ceil ((m - n) * self->lre_step), 100000) : ceil (m - n);
     guint ti              = (self->cur_sample_id + 1) / self->nwalkers;
-    
+
     runs = GSL_MIN (ncm_timer_task_estimate_by_time (self->nt, self->max_runs_time), runs);
     runs = GSL_MAX (runs / self->nwalkers + 1, self->min_runs);
     
@@ -2016,7 +2097,7 @@ ncm_fit_esmcmc_run_burnin (NcmFitESMCMC *esmcmc, guint prerun, guint ntimes)
     
     if (self->auto_trim)
       ncm_mset_catalog_trim_by_type (self->mcat, self->auto_trim_div, self->trim_type, self->mtype);
-
+    
     ncm_mset_catalog_estimate_autocorrelation_tau (self->mcat, FALSE);
     
     var       = ncm_mset_catalog_peek_current_e_var (self->mcat);
@@ -2152,17 +2233,14 @@ _ncm_fit_esmcmc_validade_mt_eval (glong i, glong f, gpointer data)
       g_array_index (self->accepted, gboolean, 0) = FALSE;
       g_mutex_unlock (&self->update_lock);
     }
-    else if (self->mtype >= NCM_FIT_RUN_MSGS_SIMPLE)
+    else if (self->mtype >= NCM_FIT_RUN_MSGS_FULL)
     {
       g_mutex_lock (&self->resample_lock);
       ncm_message ("# NcmFitESMCMC: Catalog row %5lu: m2lnL = %20.15g, recalculated to % 20.15g, diff = %8.5e, SUCCEEDED!\n",
                    k, row_m2lnL, m2lnL, diff);
       
-      if (self->mtype >= NCM_FIT_RUN_MSGS_FULL)
-      {
-        ncm_message ("# NcmFitESMCMC: row %5lu values:", k);
-        ncm_vector_log_vals (cur_row, "", "%22.15g", TRUE);
-      }
+      ncm_message ("# NcmFitESMCMC: row %5lu values:", k);
+      ncm_vector_log_vals (cur_row, "", "%22.15g", TRUE);
       
       g_mutex_unlock (&self->resample_lock);
     }
@@ -2198,7 +2276,7 @@ _ncm_fit_esmcmc_validate_mpi (NcmFitESMCMC *esmcmc, const glong i, const glong f
     g_ptr_array_add (thetastar_out_a, thetastar_out_j);
   }
   
-  ncm_mpi_job_run_array (self->mj, thetastar_in_a, thetastar_out_a);
+  ncm_mpi_job_run_array_async (self->mj, thetastar_in_a, thetastar_out_a);
   
   k = i;
   
@@ -2302,6 +2380,28 @@ ncm_fit_esmcmc_validate (NcmFitESMCMC *esmcmc, gulong pi, gulong pf)
     _ncm_fit_esmcmc_validade_mt_eval (pi, pf, esmcmc);
   }
   
+  if (self->mtype >= NCM_FIT_RUN_MSGS_SIMPLE)
+  {
+    if (g_array_index (self->accepted, gboolean, 0))
+      g_message ("# NcmFitESMCMC: samples rows [%lu, %lu) successfully validated.\n", pi, pf);
+    else
+      g_message ("# NcmFitESMCMC: some samples rows in [%lu, %lu) are invalid.\n", pi, pf);
+  }
+
   return g_array_index (self->accepted, gboolean, 0);
 }
 
+/**
+ * ncm_fit_esmcmc_peek_walker:
+ * @esmcmc: a #NcmFitESMCMC
+ *
+ * Returns: (transfer none): the currently used walker #NcmFitESMCMCWalker.
+ */
+NcmFitESMCMCWalker *
+ncm_fit_esmcmc_peek_walker (NcmFitESMCMC *esmcmc)
+{
+  NcmFitESMCMCPrivate * const self = esmcmc->priv;
+
+  return self->walker;
+}
+
