@@ -42,7 +42,9 @@
 #include "math/ncm_func_eval.h"
 #include "ncm_enum_types.h"
 
+#ifndef NUMCOSMO_GIR_SCAN
 #include <gsl/gsl_statistics_double.h>
+#endif /* NUMCOSMO_GIR_SCAN */
 
 enum
 {
@@ -253,6 +255,7 @@ _ncm_fit_mc_set_fit_obj (NcmFitMC *mc, NcmFit *fit)
   mc->mcat = ncm_mset_catalog_new (fit->mset, 1, 1, FALSE, 
                                    NCM_MSET_CATALOG_M2LNL_COLNAME, NCM_MSET_CATALOG_M2LNL_SYMBOL, 
                                    NULL);
+  ncm_mset_catalog_set_m2lnp_var (mc->mcat, 0);
 }
 
 /**
@@ -326,15 +329,16 @@ ncm_fit_mc_set_data_file (NcmFitMC *mc, const gchar *filename)
 
   if (mc->started)
   {
-    if (mc->mcat->cur_id > mc->cur_sample_id)
+    const gint mcat_cur_id = ncm_mset_catalog_get_cur_id (mc->mcat);
+    if (mcat_cur_id > mc->cur_sample_id)
     {
-      ncm_fit_mc_intern_skip (mc, mc->mcat->cur_id - mc->cur_sample_id);
-      g_assert_cmpint (mc->cur_sample_id, ==, mc->mcat->cur_id);
+      ncm_fit_mc_intern_skip (mc, mcat_cur_id - mc->cur_sample_id);
+      g_assert_cmpint (mc->cur_sample_id, ==, mcat_cur_id);
     }
-    else if (mc->mcat->cur_id < mc->cur_sample_id)
+    else if (mcat_cur_id < mc->cur_sample_id)
     {
       g_error ("ncm_fit_mc_set_data_file: Unknown error cur_id < cur_sample_id [%d < %d].", 
-               mc->mcat->cur_id, mc->cur_sample_id);
+               mcat_cur_id, mc->cur_sample_id);
     }
   }
 }
@@ -358,7 +362,7 @@ static void _ncm_fit_mc_resample_bstrap (NcmDataset *dset, NcmMSet *mset, NcmRNG
 static gint
 _ncm_fit_mc_resample (NcmFitMC *mc, NcmFit *fit)
 {
-  mc->resample (fit->lh->dset, mc->fiduc, mc->mcat->rng);
+  mc->resample (fit->lh->dset, mc->fiduc, ncm_mset_catalog_peek_rng (mc->mcat));
   mc->cur_sample_id++;
   return mc->cur_sample_id;
 }
@@ -446,7 +450,7 @@ ncm_fit_mc_set_fiducial (NcmFitMC *mc, NcmMSet *fiduc)
   if (fiduc == NULL || fiduc == mc->fit->mset)
   {
     mc->fiduc = ncm_mset_dup (mc->fit->mset, mc->ser);
-    ncm_serialize_reset (mc->ser);
+    ncm_serialize_reset (mc->ser, TRUE);
   }
   else
   {
@@ -499,6 +503,7 @@ _ncm_fit_mc_update (NcmFitMC *mc, NcmFit *fit)
         ncm_timer_task_log_elapsed (mc->nt);
         ncm_timer_task_log_mean_time (mc->nt);
         ncm_timer_task_log_time_left (mc->nt);
+        ncm_timer_task_log_cur_datetime (mc->nt);
         ncm_timer_task_log_end_datetime (mc->nt);
       }
       break;
@@ -512,6 +517,7 @@ _ncm_fit_mc_update (NcmFitMC *mc, NcmFit *fit)
       ncm_timer_task_log_elapsed (mc->nt);
       ncm_timer_task_log_mean_time (mc->nt);
       ncm_timer_task_log_time_left (mc->nt);
+      ncm_timer_task_log_cur_datetime (mc->nt);
       ncm_timer_task_log_end_datetime (mc->nt);
       break;      
   }
@@ -533,7 +539,9 @@ _ncm_fit_mc_resample_bstrap (NcmDataset *dset, NcmMSet *mset, NcmRNG *rng)
 void 
 ncm_fit_mc_start_run (NcmFitMC *mc)
 {
-  guint param_len = ncm_mset_total_len (mc->fit->mset);
+  const guint param_len  = ncm_mset_total_len (mc->fit->mset);
+  const gint mcat_cur_id = ncm_mset_catalog_get_cur_id (mc->mcat);
+  NcmRNG *mcat_rng       = ncm_mset_catalog_peek_rng (mc->mcat);
 
   if (mc->started)
     g_error ("ncm_fit_mc_start_run: run already started, run ncm_fit_mc_end_run() first.");
@@ -562,9 +570,10 @@ ncm_fit_mc_start_run (NcmFitMC *mc)
       break;
   }
 
-  if (mc->mcat->rng == NULL)
+  if (mcat_rng == NULL)
   {
     NcmRNG *rng = ncm_rng_new (NULL);
+    
     ncm_rng_set_random_seed (rng, FALSE);
     ncm_fit_mc_set_rng (mc, rng);
     if (mc->mtype > NCM_FIT_RUN_MSGS_NONE)
@@ -579,14 +588,14 @@ ncm_fit_mc_start_run (NcmFitMC *mc)
   ncm_mset_catalog_set_sync_interval (mc->mcat, NCM_FIT_MC_MIN_SYNC_INTERVAL);
   
   ncm_mset_catalog_sync (mc->mcat, TRUE);
-  if (mc->mcat->cur_id > mc->cur_sample_id)
+  if (mcat_cur_id > mc->cur_sample_id)
   {
-    ncm_fit_mc_intern_skip (mc, mc->mcat->cur_id - mc->cur_sample_id);
-    g_assert_cmpint (mc->cur_sample_id, ==, mc->mcat->cur_id);
+    ncm_fit_mc_intern_skip (mc, mcat_cur_id - mc->cur_sample_id);
+    g_assert_cmpint (mc->cur_sample_id, ==, mcat_cur_id);
   }
-  else if (mc->mcat->cur_id < mc->cur_sample_id)
+  else if (mcat_cur_id < mc->cur_sample_id)
     g_error ("ncm_fit_mc_set_data_file: Unknown error cur_id < cur_sample_id [%d < %d].", 
-             mc->mcat->cur_id, mc->cur_sample_id);
+             mcat_cur_id, mc->cur_sample_id);
   
 }
 
@@ -666,7 +675,9 @@ ncm_fit_mc_intern_skip (NcmFitMC *mc, guint n)
 void 
 ncm_fit_mc_set_first_sample_id (NcmFitMC *mc, gint first_sample_id)
 {
-  if (mc->mcat->first_id == first_sample_id)
+  const gint mcat_first_id = ncm_mset_catalog_get_first_id (mc->mcat);
+  
+  if (mcat_first_id == first_sample_id)
     return;
 
   if (!mc->started)
@@ -674,7 +685,7 @@ ncm_fit_mc_set_first_sample_id (NcmFitMC *mc, gint first_sample_id)
 
   if (first_sample_id <= mc->cur_sample_id)
     g_error ("ncm_fit_mc_set_first_sample_id: cannot move first sample id backwards to: %d, catalog first id: %d, current sample id: %d.",
-             first_sample_id, mc->mcat->first_id, mc->cur_sample_id);
+             first_sample_id, mcat_first_id, mc->cur_sample_id);
 
   ncm_mset_catalog_set_first_id (mc->mcat, first_sample_id);
   ncm_fit_mc_intern_skip (mc, first_sample_id - mc->cur_sample_id - 1);
@@ -768,7 +779,7 @@ _ncm_fit_mc_dup_fit (gpointer userdata)
   g_mutex_lock (&mc->dup_fit);
   {
     NcmFit *fit = ncm_fit_dup (mc->fit, mc->ser);
-    ncm_serialize_reset (mc->ser);
+    ncm_serialize_reset (mc->ser, TRUE);
     g_mutex_unlock (&mc->dup_fit);
     return fit;
   }
@@ -928,9 +939,11 @@ ncm_fit_mc_run_lre (NcmFitMC *mc, guint prerun, gdouble lre)
 void
 ncm_fit_mc_mean_covar (NcmFitMC *mc)
 {
+  NcmMSet *mset = ncm_mset_catalog_peek_mset (mc->mcat);
+  
   ncm_mset_catalog_get_mean (mc->mcat, &mc->fit->fstate->fparams);
   ncm_mset_catalog_get_covar (mc->mcat, &mc->fit->fstate->covar);
-  ncm_mset_fparams_set_vector (mc->mcat->mset, mc->fit->fstate->fparams);
+  ncm_mset_fparams_set_vector (mset, mc->fit->fstate->fparams);
   mc->fit->fstate->has_covar = TRUE;
 }
 
