@@ -688,6 +688,50 @@ ncm_lapack_dsyevd (gchar jobz, gchar uplo, gint n, gdouble *a, gint lda, gdouble
 #endif
 }
 
+/**
+ * ncm_lapack_dsysv:
+ * @uplo: UPLO is CHARACTER*1
+ * @n: N is INTEGER
+ * @nrhs: NRHS is INTEGER
+ * @a: A is DOUBLE PRECISION array, dimension (LDA,N)
+ * @lda: LDA is INTEGER
+ * @ipiv: IPIV is INTEGER array, dimension (N)
+ * @b: B is DOUBLE PRECISION array, dimension (LDB,NRHS)
+ * @ldb: LDB is INTEGER
+ * @work: WORK is DOUBLE PRECISION array, dimension (MAX(1,LWORK))
+ * @lwork: LWORK is INTEGER
+ * 
+ * # Purpose #
+ * 
+ * DSYSV uses the diagonal pivoting factorization to compute the
+ * solution to a real system of linear equations A * X = B,
+ * where A is an N-by-N symmetric matrix and X and B are N-by-NRHS
+ * matrices.
+ * 
+ * Returns: INFO is INTEGER
+ * - = 0: successful exit
+ * - < 0: if INFO = -i, the i-th argument had an illegal value
+ * - > 0: if INFO = i, and i is
+ * - <= N:  D(i,i) is exactly zero.  The factorization
+ *   has been completed but the factor D is exactly
+ *   singular, so the solution could not be computed.
+ */
+gint
+ncm_lapack_dsysv (gchar uplo, gint n, gint nrhs, gdouble *a, gint lda, gint *ipiv, gdouble *b, gint ldb, gdouble *work, gint lwork)
+{
+#if defined (HAVE_LAPACK) && defined (HAVE_DSYSV_)
+  gint info = 0;
+  uplo      = _NCM_LAPACK_CONV_UPLO (uplo);
+
+  dsysv_ (&uplo, &n, &nrhs, a, &lda, ipiv, b, &ldb, work, &lwork, &info);
+
+  return info;
+#else /* No fall back */
+    g_error ("ncm_lapack_dsysv: lapack not present, no fallback implemented.");
+#endif
+}
+
+
 /**
  * ncm_lapack_dsysvx:
  * @fact: FACT is CHARACTER*1
@@ -709,21 +753,21 @@ ncm_lapack_dsyevd (gchar jobz, gchar uplo, gint n, gdouble *a, gint lda, gdouble
  * @work: WORK is DOUBLE PRECISION array, dimension (MAX(1,LWORK))
  * @lwork: LWORK is INTEGER
  * @iwork: IWORK is INTEGER array, dimension (N)
- * 
+ *
  * # Purpose #
- * 
+ *
  * DSYSVX uses the diagonal pivoting factorization to compute the
  * solution to a real system of linear equations A * X = B,
  * where A is an N-by-N symmetric matrix and X and B are N-by-NRHS
  * matrices.
- * 
+ *
  * Error bounds on the solution and a condition estimate are also
  * provided.
- * 
+ *
  * # Description #
- * 
+ *
  * The following steps are performed:
- * 
+ *
  * 1. If FACT = 'N', the diagonal pivoting method is used to factor A.
  *    The form of the factorization is
  * 		- A = U * D * U**T,  if UPLO = 'U', or
@@ -766,11 +810,11 @@ ncm_lapack_dsysvx (gchar fact, gchar uplo, gint n, gint nrhs, gdouble *a, gint l
   gint info = 0;
   uplo      = _NCM_LAPACK_CONV_UPLO (uplo);
 	
-	dsysvx_ (&fact, &uplo, &n, &nrhs, a, &lda, af, &ldaf, ipiv, b, &ldb, x, &ldx, rcond, ferr, berr, work, &lwork, iwork, &info);
+  dsysvx_ (&fact, &uplo, &n, &nrhs, a, &lda, af, &ldaf, ipiv, b, &ldb, x, &ldx, rcond, ferr, berr, work, &lwork, iwork, &info);
 
-	return info;
+  return info;
 #else /* No fall back */
-	g_error ("ncm_lapack_dsytrs: lapack not present, no fallback implemented.");
+  g_error ("ncm_lapack_dsysvx: lapack not present, no fallback implemented.");
 #endif
 }
 
@@ -806,14 +850,14 @@ ncm_lapack_dgeev (gchar jobvl, gchar jobvr, gint n, gdouble *a, gint lda, gdoubl
 {
 #if defined (HAVE_LAPACK) && defined (HAVE_DGEEV_)
   gint info = 0;
-	
-	/* swap L <=> R : col-major <=> row-major */
+
+  /* swap L <=> R : col-major <=> row-major */
   dgeev_ (&jobvr, &jobvl, &n, a, &lda, wr, wi, vr, &ldvr, vl, &ldvl, work, &lwork, &info);  
 
-	return info;
+  return info;
 #else /* No fall back. */
-	g_error ("ncm_lapack_dgeev: no lapack support!");
-	return -1;
+  g_error ("ncm_lapack_dgeev: no lapack support!");
+  return -1;
 #endif
 }
 
@@ -859,12 +903,12 @@ ncm_lapack_dgeevx (gchar balanc, gchar jobvl, gchar jobvr, gchar sense, gint n,
 #if defined (HAVE_LAPACK) && defined (HAVE_DGEEVX_)
   gint info = 0;
 	
-	/* swap L <=> R : col-major <=> row-major */
-	dgeevx_ (&balanc, &jobvr, &jobvl, &sense, &n, a, &lda, wr, wi, vr, &ldvr, vl, &ldvl, ilo, ihi, scale, abnrm, rconde, rcondv, work, &lwork, iwork, &info);
+  /* swap L <=> R : col-major <=> row-major */
+  dgeevx_ (&balanc, &jobvr, &jobvl, &sense, &n, a, &lda, wr, wi, vr, &ldvr, vl, &ldvl, ilo, ihi, scale, abnrm, rconde, rcondv, work, &lwork, iwork, &info);
 
-	return info;
+  return info;
 #else /* No fall back. */
-	g_error ("ncm_lapack_dgeev: no lapack support!");
+	g_error ("ncm_lapack_dgeevx: no lapack support!");
 	return -1;
 #endif
 }
@@ -1167,3 +1211,81 @@ ncm_lapack_dggglm_run (GArray *ws, NcmMatrix *L, NcmMatrix *X, NcmVector *p, Ncm
   return -1;
 #endif
 }
+
+/**
+ * ncm_lapack_dgels:
+ * @trans: is a char
+ * = 'N': the linear system involves A
+ * = 'T': the linear system involves A**T
+ * @m: is an integer. The number of rows of the matrix A.  M >= 0
+ * @n: is an integer. The number of columns of the matrix A.  N >= 0
+ * @nrhs: is an integer. The number of right hand sides, i.e., the number of columns of the matrices B and X. NRHS >=0
+ * @a: array of doubles with dimension (@n, @lda)
+ * On entry, the M-by-N matrix A.
+ * On exit,
+ *   if M >= N, A is overwritten by details of its QR factorization as returned by DGEQRF
+ *   if M <  N, A is overwritten by details of its LQ factorization as returned by DGELQF
+ * @lda: The leading dimension of the array @a, @lda >= max (1,@n)
+ * @b: array of doubles with dimension (@n, @ldb)
+ * On entry, the matrix B of right hand side vectors, stored
+ * columnwise; B is M-by-NRHS if TRANS = 'N', or N-by-NRHS
+ * if TRANS = 'T'.
+ * On exit, if INFO = 0, B is overwritten by the solution
+ * vectors, stored columnwise:
+ * if TRANS = 'N' and m >= n, rows 1 to n of B contain the least
+ * squares solution vectors; the residual sum of squares for the
+ * solution in each column is given by the sum of squares of
+ * elements N+1 to M in that column;
+ * if TRANS = 'N' and m < n, rows 1 to N of B contain the
+ * minimum norm solution vectors;
+ * if TRANS = 'T' and m >= n, rows 1 to M of B contain the
+ * minimum norm solution vectors;
+ * if TRANS = 'T' and m < n, rows 1 to M of B contain the
+ * least squares solution vectors; the residual sum of squares
+ * for the solution in each column is given by the sum of
+ * squares of elements M+1 to N in that column.
+ * @ldb: The leading dimension of the array @b, @ldb >= max (1, @n)
+ * @work: WORK is DOUBLE PRECISION array, dimension (4*N)
+ * @lwork: LWORK is INTEGER
+ *
+ * DGELS solves overdetermined or underdetermined real linear systems
+ * involving an M-by-N matrix A, or its transpose, using a QR or LQ
+ * factorization of A.  It is assumed that A has full rank.
+ *
+ * The following options are provided:
+ *
+ * 1. If TRANS = 'N' and m >= n:  find the least squares solution of
+ *    an overdetermined system, i.e., solve the least squares problem
+ *                 minimize || B - A*X ||.
+ *
+ * 2. If TRANS = 'N' and m < n:  find the minimum norm solution of
+ *    an underdetermined system A * X = B.
+ *
+ * 3. If TRANS = 'T' and m >= n:  find the minimum norm solution of
+ *    an underdetermined system A**T * X = B.
+ *
+ * 4. If TRANS = 'T' and m < n:  find the least squares solution of
+ *    an overdetermined system, i.e., solve the least squares problem
+ *                 minimize || B - A**T * X ||.
+ *
+ * Several right hand side vectors b and solution vectors x can be
+ * handled in a single call; they are stored as the columns of the
+ * M-by-NRHS right hand side matrix B and the N-by-NRHS solution
+ * matrix X.
+ */
+gint
+ncm_lapack_dgels (gchar trans, const gint m, const gint n, const gint nrhs, gdouble *a, const gint lda, gdouble *b, const gint ldb, double *work, const gint lwork)
+{
+#if defined (HAVE_LAPACK) && defined (HAVE_DGELS_)
+  gint info = 0;
+
+  trans = _NCM_LAPACK_CONV_TRANS (trans);
+
+  dgels_ (&trans, &n, &m, &nrhs, a, &lda, b, &ldb, work, &lwork, &info);
+
+  return info;
+#else /* No fall back */
+    g_error ("ncm_lapack_dgels: lapack not present, no fallback implemented.");
+#endif
+}
+
