@@ -29,7 +29,7 @@
  * @short_description: Matrix object representing an array of doubles.
  *
  * This object defines the functions for allocating and accessing matrices.
- * Also includes serveral matrix operations.
+ * Also includes several matrix operations.
  *
  */
 
@@ -564,6 +564,29 @@ ncm_matrix_get_row (NcmMatrix *cm, const guint row)
   return cv;
 }
 
+/**
+ * ncm_matrix_as_vector:
+ * @cm: a #NcmMatrix
+ *
+ * Creates a vector containing the row-wise concatenation
+ * of the matrix @cm. It requires a matrix with tda==ncols.
+ *
+ * Returns: (transfer full): A #NcmVector.
+ */
+NcmVector *
+ncm_matrix_as_vector (NcmMatrix *cm)
+{
+  const guint nrows = ncm_matrix_nrows (cm);
+  const guint ncols = ncm_matrix_ncols (cm);
+  const guint len   = nrows * ncols;
+
+  NcmVector *v = ncm_vector_new_full (ncm_matrix_data (cm), len, 1, ncm_matrix_ref (cm), (GDestroyNotify)&ncm_matrix_free);
+
+  g_assert (ncm_matrix_tda (cm) == ncm_matrix_ncols (cm));
+
+  return v;
+}
+
 /**
  * ncm_matrix_set_from_variant:
  * @cm: a #NcmMatrix
@@ -952,7 +975,7 @@ ncm_matrix_cmp_diag (const NcmMatrix *cm1, const NcmMatrix *cm2, const gdouble s
  * @UL: char indicating 'U'pper or 'L'ower matrix
  *
  * If @UL == 'U' copy the upper triangle over the lower.
- * If @UL == 'L' copy the lower triangle over the lower.
+ * If @UL == 'L' copy the lower triangle over the upper.
  *
  */
 void
@@ -1092,7 +1115,7 @@ ncm_matrix_dgemm (NcmMatrix *cm, gchar TransA, gchar TransB, const gdouble alpha
  * @cm: a #NcmMatrix
  * @UL: char indicating 'U'pper or 'L'ower matrix
  *
- * Calculates inplace the Cholesky decomposition for a symmetric positive
+ * Calculates in-place the Cholesky decomposition for a symmetric positive
  * definite matrix.
  *
  */
@@ -1167,7 +1190,7 @@ ncm_matrix_cholesky_lndet (NcmMatrix *cm)
  * @b: a #NcmVector
  * @UL: char indicating 'U'pper or 'L'ower matrix
  *
- * Calculates inplace the Cholesky decomposition for a symmetric positive
+ * Calculates in-place the Cholesky decomposition for a symmetric positive
  * definite matrix and solve the system $A x = B$ where $A=$@cm and $B$=@b.
  *
  */
@@ -1504,6 +1527,118 @@ ncm_matrix_triang_to_sym (NcmMatrix *cm, gchar UL, gboolean zero, NcmMatrix *sym
     g_assert_not_reached ();
 }
 
+/**
+ * ncm_matrix_square_to_sym:
+ * @cm: $M$ a #NcmMatrix
+ * @NT: char indicating 'N' or 'T'
+ * @UL: char indicating 'U'pper or 'L'ower matrix
+ * @sym: a #NcmMatrix to store the result
+ *
+ * Computes the symmetric matrix $M^\intercal \times M$ if
+ * @NT == 'T' or $M\times M^\intercal$ if @NT == 'N'. The result
+ * is stored in the upper/lower triangle if @UL='U'/'L'
+ *
+ *
+ */
+void
+ncm_matrix_square_to_sym (NcmMatrix *cm, gchar NT, gchar UL, NcmMatrix *sym)
+{
+  const guint nrows = ncm_matrix_nrows (cm);
+  const guint ncols = ncm_matrix_ncols (cm);
+  const CBLAS_UPLO Uplo       = (UL == 'U') ? CblasUpper : CblasLower;
+  CBLAS_TRANSPOSE Trans;
+  gint n, k;
+
+  if (NT == 'N')
+  {
+    Trans = CblasNoTrans;
+    n     = nrows;
+    k     = ncols;
+  }
+  else
+  {
+    Trans = CblasTrans;
+    n     = ncols;
+    k     = nrows;
+  }
+
+  g_assert_cmpuint (ncm_matrix_ncols (sym), ==, n);
+  g_assert_cmpuint (ncm_matrix_ncols (sym), ==, ncm_matrix_nrows (sym));
+
+  cblas_dsyrk (CblasRowMajor, Uplo, Trans, n, k,
+               1.0, ncm_matrix_data (cm),  ncm_matrix_tda (cm),
+               0.0, ncm_matrix_data (sym), ncm_matrix_tda (sym));
+}
+
+/**
+ * ncm_matrix_update_vector:
+ * @cm: $M$ a #NcmMatrix
+ * @NT: char indicating 'N' or 'T'
+ * @alpha: a double $\alpha$
+ * @v: a #NcmVector to update
+ * @beta: a double $\beta$
+ * @u: a #NcmVector to store the result
+ *
+ * Computes the matrix - vector product $u = \alpha M v + \beta u$
+ * if @NT == 'N' or $u = M^\intercal v$ if @NT == 'T'
+ * and stores the result in @u.
+ */
+void
+ncm_matrix_update_vector (NcmMatrix *cm, gchar NT, const gdouble alpha, NcmVector *v, const gdouble beta, NcmVector *u)
+{
+  const guint nrows = ncm_matrix_nrows (cm);
+  const guint ncols = ncm_matrix_ncols (cm);
+  CBLAS_TRANSPOSE Trans;
+
+  if (NT == 'N')
+  {
+    Trans = CblasNoTrans;
+    g_assert_cmpuint (nrows, ==, ncm_vector_len (u));
+    g_assert_cmpuint (ncols, ==, ncm_vector_len (v));
+  }
+  else
+  {
+    Trans = CblasTrans;
+    g_assert_cmpuint (nrows, ==, ncm_vector_len (v));
+    g_assert_cmpuint (ncols, ==, ncm_vector_len (u));
+  }
+
+  cblas_dgemv (CblasRowMajor, Trans, nrows, ncols,
+      alpha, ncm_matrix_data (cm), ncm_matrix_tda (cm),
+      ncm_vector_data (v), ncm_vector_stride (v),
+      beta, ncm_vector_data (u), ncm_vector_stride (u));
+}
+
+/**
+ * ncm_matrix_sym_update_vector:
+ * @cm: $M$ a #NcmMatrix
+ * @UL: char indicating 'U'pper or 'L'ower matrix
+ * @alpha: a double $\alpha$
+ * @v: a #NcmVector to update
+ * @beta: a double $\beta$
+ * @u: a #NcmVector to store the result
+ *
+ * Computes the matrix - vector product $u = \alpha M v + \beta u$
+ * if @NT == 'N' or $u = M^\intercal v$ if @NT == 'T'
+ * and stores the result in @u. This function assumes
+ * that $M$ is symmetric and it´s stored in the Upper/Lower
+ * triangle if @UL == 'U'/'L'.
+ */
+void
+ncm_matrix_sym_update_vector (NcmMatrix *cm, gchar UL, const gdouble alpha, NcmVector *v, const gdouble beta, NcmVector *u)
+{
+  const guint nrows     = ncm_matrix_nrows (cm);
+  const guint ncols     = ncm_matrix_ncols (cm);
+  const CBLAS_UPLO Uplo = (UL == 'U') ? CblasUpper : CblasLower;
+
+  g_assert_cmpuint (nrows, ==, ncols);
+
+  cblas_dsymv (CblasRowMajor, Uplo, nrows,
+               alpha, ncm_matrix_data (cm), ncm_matrix_tda (cm),
+               ncm_vector_data (v), ncm_vector_stride (v),
+               beta, ncm_vector_data (u), ncm_vector_stride (u));
+}
+
 /**
  * ncm_matrix_log_vals:
  * @cm: a #NcmMatrix
@@ -1741,6 +1876,21 @@ ncm_matrix_cov_dup_cor (const NcmMatrix *cov)
  * Returns: The (@i,@j)-th element of the matrix @cm.
  */
 
+/**
+ * ncm_matrix_get_colmajor:
+ * @cm: a constant #NcmMatrix
+ * @i: row index
+ * @j: column index
+ *
+ * Gets the (@i,@j)-th component of @cm assuming
+ * a [column-major order](https://en.wikipedia.org/wiki/Row-_and_column-major_order).
+ *
+ * All column-major methods should be used carefully, they are inconsistent with
+ * most other methods and are used mainly to interface with Fortran sub-routines.
+ *
+ * Returns: The (@i,@j)-th element of the matrix @cm.
+ */
+
 /**
  * ncm_matrix_ptr:
  * @cm: a #NcmMatrix
@@ -1777,7 +1927,11 @@ ncm_matrix_cov_dup_cor (const NcmMatrix *cov)
  * @j: column index
  * @val: a double
  *
- * This function sets the value of the (@i,@j)-th element of the matrix @cm to @val considering it being in the [column-major order](https://en.wikipedia.org/wiki/Row-_and_column-major_order).
+ * This function sets the value of the (@i,@j)-th element of the matrix @cm to @val
+ * considering it being in the [column-major order](https://en.wikipedia.org/wiki/Row-_and_column-major_order).
+ *
+ * All column-major methods should be used carefully, they are inconsistent with
+ * most other methods and are used mainly to interface with Fortran sub-routines.
  *
  */
 
@@ -1930,11 +2084,25 @@ ncm_matrix_cov_dup_cor (const NcmMatrix *cov)
  * @cm1: a #NcmMatrix
  * @cm2: a #NcmMatrix
  *
- * This function copies the elements of the matrix @cm1 into the matrix @cm2.
+ * This function copies the elements of the matrix @cm2 into the matrix @cm1.
  * The two matrices must have the same size.
  *
  */
 
+/**
+ * ncm_matrix_memcpy_to_colmajor:
+ * @cm1: a #NcmMatrix
+ * @cm2: a #NcmMatrix
+ *
+ * This function copies the elements of the matrix @cm2 into the matrix @cm1.
+ * The two matrices must have the same size. The elements are written in @cm1
+ * in [column-major order](https://en.wikipedia.org/wiki/Row-_and_column-major_order)
+ * order.
+ *
+ * All column-major methods should be used carefully, they are inconsistent with
+ * most other methods and are used mainly to interface with Fortran sub-routines.
+ */
+
 /**
  * ncm_matrix_set_col:
  * @cm: a #NcmMatrix
