@@ -108,6 +108,7 @@ const NcmMatrix *ncm_matrix_const_new_variant (GVariant *var);
 NcmMatrix *ncm_matrix_get_submatrix (NcmMatrix *cm, const guint k1, const guint k2, const guint nrows, const guint ncols);
 NcmVector *ncm_matrix_get_col (NcmMatrix *cm, const guint col);
 NcmVector *ncm_matrix_get_row (NcmMatrix *cm, const guint row);
+NcmVector *ncm_matrix_as_vector (NcmMatrix *cm);
 
 void ncm_matrix_set_from_variant (NcmMatrix *cm, GVariant *var);
 GVariant *ncm_matrix_get_variant (NcmMatrix *cm);
@@ -118,6 +119,7 @@ void ncm_matrix_set_from_array (NcmMatrix *cm, GArray *a);
 
 NCM_INLINE const NcmMatrix *ncm_matrix_new_gsl_const (gsl_matrix *gm);
 NCM_INLINE gdouble ncm_matrix_get (const NcmMatrix *cm, const guint i, const guint j);
+NCM_INLINE gdouble ncm_matrix_get_colmajor (const NcmMatrix *cm, const guint i, const guint j);
 NCM_INLINE gdouble *ncm_matrix_ptr (NcmMatrix *cm, const guint i, const guint j);
 NCM_INLINE const gdouble *ncm_matrix_const_ptr (const NcmMatrix *cm, const guint i, const guint j);
 NCM_INLINE GArray *ncm_matrix_get_array (NcmMatrix *cm);
@@ -142,6 +144,7 @@ NCM_INLINE void ncm_matrix_get_diag (NcmMatrix *cm, NcmVector *diag);
 NCM_INLINE void ncm_matrix_set_diag (NcmMatrix *cm, NcmVector *diag);
 
 NCM_INLINE void ncm_matrix_memcpy (NcmMatrix *cm1, const NcmMatrix *cm2);
+NCM_INLINE void ncm_matrix_memcpy_to_colmajor (NcmMatrix *cm1, const NcmMatrix *cm2);
 NCM_INLINE void ncm_matrix_set_col (NcmMatrix *cm, const guint n, const NcmVector *cv);
 NCM_INLINE void ncm_matrix_set_row (NcmMatrix *cm, const guint n, const NcmVector *cv);
 NCM_INLINE gdouble ncm_matrix_fast_get (NcmMatrix *cm, const guint ij);
@@ -183,6 +186,10 @@ gint ncm_matrix_nearPD (NcmMatrix *cm, gchar UL, gboolean cholesky_decomp, const
 void ncm_matrix_sym_exp_cholesky (NcmMatrix *cm, gchar UL, NcmMatrix *exp_cm_dec);
 void ncm_matrix_sym_posdef_log (NcmMatrix *cm, gchar UL, NcmMatrix *ln_cm);
 void ncm_matrix_triang_to_sym (NcmMatrix *cm, gchar UL, gboolean zero, NcmMatrix *sym);
+void ncm_matrix_square_to_sym (NcmMatrix *cm, gchar NT, gchar UL, NcmMatrix *sym);
+void ncm_matrix_update_vector (NcmMatrix *cm, gchar NT, const gdouble alpha, NcmVector *v, const gdouble beta, NcmVector *u);
+void ncm_matrix_sym_update_vector (NcmMatrix *cm, gchar UL, const gdouble alpha, NcmVector *v, const gdouble beta, NcmVector *u);
+
 void ncm_matrix_log_vals (NcmMatrix *cm, gchar *prefix, gchar *format);
 
 void ncm_matrix_fill_rand_cor (NcmMatrix *cm, const gdouble cor_level, NcmRNG *rng);
@@ -214,6 +221,12 @@ ncm_matrix_get (const NcmMatrix *cm, const guint i, const guint j)
   return gsl_matrix_get (ncm_matrix_const_gsl (cm), i, j);
 }
 
+NCM_INLINE gdouble
+ncm_matrix_get_colmajor (const NcmMatrix *cm, const guint i, const guint j)
+{
+  return ncm_matrix_const_data (cm)[i + ncm_matrix_nrows (cm) * j];
+}
+
 NCM_INLINE gdouble *
 ncm_matrix_ptr (NcmMatrix *cm, guint i, guint j)
 {
@@ -370,15 +383,15 @@ ncm_matrix_memcpy (NcmMatrix *cm1, const NcmMatrix *cm2)
   const guint nrows = ncm_matrix_nrows (cm1);
   const guint ncols = ncm_matrix_ncols (cm1);
   const guint total = nrows * ncols;
-  
+
   g_assert_cmpuint (nrows, ==, ncm_matrix_nrows (cm2));
   g_assert_cmpuint (ncols, ==, ncm_matrix_ncols (cm2));
-  
+
   if ((ncm_matrix_tda (cm1) != ncols) || (ncm_matrix_tda (cm2) != ncm_matrix_ncols (cm2)))
   {
     register guint i;
     const guint ncols_bytes = sizeof (gdouble) * ncols;
-    
+
     for (i = 0; i < nrows; i++)
       memcpy (ncm_matrix_ptr (cm1, i, 0), ncm_matrix_const_ptr (cm2, i, 0), ncols_bytes);
   }
@@ -388,6 +401,26 @@ ncm_matrix_memcpy (NcmMatrix *cm1, const NcmMatrix *cm2)
   }
 }
 
+NCM_INLINE void
+ncm_matrix_memcpy_to_colmajor (NcmMatrix *cm1, const NcmMatrix *cm2)
+{
+  const guint nrows = ncm_matrix_nrows (cm1);
+  const guint ncols = ncm_matrix_ncols (cm1);
+  register guint i;
+  
+  g_assert_cmpuint (nrows, ==, ncm_matrix_nrows (cm2));
+  g_assert_cmpuint (ncols, ==, ncm_matrix_ncols (cm2));
+  
+  for (i = 0; i < nrows; i++)
+  {
+    register guint j;
+    for (j = 0; j < ncols; j++)
+    {
+      ncm_matrix_set_colmajor (cm1, i, j, ncm_matrix_get (cm2, i, j));
+    }
+  }
+}
+
 NCM_INLINE void
 ncm_matrix_set_col (NcmMatrix *cm, const guint n, const NcmVector *cv)
 {
